/****************************************************************************
** Meta object code from reading C++ file 'kreversiview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kreversi-17.08.3/kreversiview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kreversiview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReversiView_t {
    QByteArrayData data[16];
    char stringdata0[182];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReversiView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReversiView_t qt_meta_stringdata_KReversiView = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KReversiView"
QT_MOC_LITERAL(1, 13, 8), // "userMove"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 11), // "KReversiPos"
QT_MOC_LITERAL(4, 35, 15), // "setShowLastMove"
QT_MOC_LITERAL(5, 51, 4), // "show"
QT_MOC_LITERAL(6, 56, 17), // "setShowLegalMoves"
QT_MOC_LITERAL(7, 74, 8), // "slotHint"
QT_MOC_LITERAL(8, 83, 12), // "onPlayerMove"
QT_MOC_LITERAL(9, 96, 3), // "row"
QT_MOC_LITERAL(10, 100, 3), // "col"
QT_MOC_LITERAL(11, 104, 11), // "updateBoard"
QT_MOC_LITERAL(12, 116, 16), // "gameMoveFinished"
QT_MOC_LITERAL(13, 133, 8), // "gameOver"
QT_MOC_LITERAL(14, 142, 19), // "whitePlayerCantMove"
QT_MOC_LITERAL(15, 162, 19) // "blackPlayerCantMove"

    },
    "KReversiView\0userMove\0\0KReversiPos\0"
    "setShowLastMove\0show\0setShowLegalMoves\0"
    "slotHint\0onPlayerMove\0row\0col\0updateBoard\0"
    "gameMoveFinished\0gameOver\0whitePlayerCantMove\0"
    "blackPlayerCantMove"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReversiView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   67,    2, 0x0a /* Public */,
       6,    1,   70,    2, 0x0a /* Public */,
       7,    0,   73,    2, 0x0a /* Public */,
       8,    2,   74,    2, 0x08 /* Private */,
      11,    0,   79,    2, 0x08 /* Private */,
      12,    0,   80,    2, 0x08 /* Private */,
      13,    0,   81,    2, 0x08 /* Private */,
      14,    0,   82,    2, 0x08 /* Private */,
      15,    0,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KReversiView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReversiView *_t = static_cast<KReversiView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->userMove((*reinterpret_cast< KReversiPos(*)>(_a[1]))); break;
        case 1: _t->setShowLastMove((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setShowLegalMoves((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->slotHint(); break;
        case 4: _t->onPlayerMove((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->updateBoard(); break;
        case 6: _t->gameMoveFinished(); break;
        case 7: _t->gameOver(); break;
        case 8: _t->whitePlayerCantMove(); break;
        case 9: _t->blackPlayerCantMove(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KReversiView::*_t)(KReversiPos );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiView::userMove)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KReversiView::staticMetaObject = {
    { &KgDeclarativeView::staticMetaObject, qt_meta_stringdata_KReversiView.data,
      qt_meta_data_KReversiView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReversiView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReversiView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReversiView.stringdata0))
        return static_cast<void*>(this);
    return KgDeclarativeView::qt_metacast(_clname);
}

int KReversiView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KgDeclarativeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KReversiView::userMove(KReversiPos _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
