/****************************************************************************
** Meta object code from reading C++ file 'kexthighscore_tab.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kreversi-17.08.3/kexthighscore_tab.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kexthighscore_tab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KExtHighscore__PlayersCombo_t {
    QByteArrayData data[7];
    char stringdata0[85];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__PlayersCombo_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__PlayersCombo_t qt_meta_stringdata_KExtHighscore__PlayersCombo = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KExtHighscore::PlayersCombo"
QT_MOC_LITERAL(1, 28, 14), // "playerSelected"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 1), // "i"
QT_MOC_LITERAL(4, 46, 11), // "allSelected"
QT_MOC_LITERAL(5, 58, 12), // "noneSelected"
QT_MOC_LITERAL(6, 71, 13) // "activatedSlot"

    },
    "KExtHighscore::PlayersCombo\0playerSelected\0"
    "\0i\0allSelected\0noneSelected\0activatedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__PlayersCombo[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       4,    0,   37,    2, 0x06 /* Public */,
       5,    0,   38,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   39,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::UInt,    3,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void KExtHighscore::PlayersCombo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PlayersCombo *_t = static_cast<PlayersCombo *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->playerSelected((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 1: _t->allSelected(); break;
        case 2: _t->noneSelected(); break;
        case 3: _t->activatedSlot((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (PlayersCombo::*_t)(uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PlayersCombo::playerSelected)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PlayersCombo::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PlayersCombo::allSelected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (PlayersCombo::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PlayersCombo::noneSelected)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KExtHighscore::PlayersCombo::staticMetaObject = {
    { &QComboBox::staticMetaObject, qt_meta_stringdata_KExtHighscore__PlayersCombo.data,
      qt_meta_data_KExtHighscore__PlayersCombo,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::PlayersCombo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::PlayersCombo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__PlayersCombo.stringdata0))
        return static_cast<void*>(this);
    return QComboBox::qt_metacast(_clname);
}

int KExtHighscore::PlayersCombo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KExtHighscore::PlayersCombo::playerSelected(uint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KExtHighscore::PlayersCombo::allSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KExtHighscore::PlayersCombo::noneSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
struct qt_meta_stringdata_KExtHighscore__AdditionalTab_t {
    QByteArrayData data[5];
    char stringdata0[59];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__AdditionalTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__AdditionalTab_t qt_meta_stringdata_KExtHighscore__AdditionalTab = {
    {
QT_MOC_LITERAL(0, 0, 28), // "KExtHighscore::AdditionalTab"
QT_MOC_LITERAL(1, 29, 14), // "playerSelected"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 1), // "i"
QT_MOC_LITERAL(4, 47, 11) // "allSelected"

    },
    "KExtHighscore::AdditionalTab\0"
    "playerSelected\0\0i\0allSelected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__AdditionalTab[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x08 /* Private */,
       4,    0,   27,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::UInt,    3,
    QMetaType::Void,

       0        // eod
};

void KExtHighscore::AdditionalTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AdditionalTab *_t = static_cast<AdditionalTab *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->playerSelected((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 1: _t->allSelected(); break;
        default: ;
        }
    }
}

const QMetaObject KExtHighscore::AdditionalTab::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KExtHighscore__AdditionalTab.data,
      qt_meta_data_KExtHighscore__AdditionalTab,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::AdditionalTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::AdditionalTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__AdditionalTab.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KExtHighscore::AdditionalTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__StatisticsTab_t {
    QByteArrayData data[1];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__StatisticsTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__StatisticsTab_t qt_meta_stringdata_KExtHighscore__StatisticsTab = {
    {
QT_MOC_LITERAL(0, 0, 28) // "KExtHighscore::StatisticsTab"

    },
    "KExtHighscore::StatisticsTab"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__StatisticsTab[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KExtHighscore::StatisticsTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KExtHighscore::StatisticsTab::staticMetaObject = {
    { &AdditionalTab::staticMetaObject, qt_meta_stringdata_KExtHighscore__StatisticsTab.data,
      qt_meta_data_KExtHighscore__StatisticsTab,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::StatisticsTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::StatisticsTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__StatisticsTab.stringdata0))
        return static_cast<void*>(this);
    return AdditionalTab::qt_metacast(_clname);
}

int KExtHighscore::StatisticsTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AdditionalTab::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__HistogramTab_t {
    QByteArrayData data[1];
    char stringdata0[28];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__HistogramTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__HistogramTab_t qt_meta_stringdata_KExtHighscore__HistogramTab = {
    {
QT_MOC_LITERAL(0, 0, 27) // "KExtHighscore::HistogramTab"

    },
    "KExtHighscore::HistogramTab"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__HistogramTab[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KExtHighscore::HistogramTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KExtHighscore::HistogramTab::staticMetaObject = {
    { &AdditionalTab::staticMetaObject, qt_meta_stringdata_KExtHighscore__HistogramTab.data,
      qt_meta_data_KExtHighscore__HistogramTab,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::HistogramTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HistogramTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__HistogramTab.stringdata0))
        return static_cast<void*>(this);
    return AdditionalTab::qt_metacast(_clname);
}

int KExtHighscore::HistogramTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AdditionalTab::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
