/****************************************************************************
** Meta object code from reading C++ file 'kreversigame.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kreversi-17.08.3/kreversigame.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kreversigame.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReversiGame_t {
    QByteArrayData data[17];
    char stringdata0[220];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReversiGame_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReversiGame_t qt_meta_stringdata_KReversiGame = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KReversiGame"
QT_MOC_LITERAL(1, 13, 8), // "gameOver"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 12), // "boardChanged"
QT_MOC_LITERAL(4, 36, 12), // "moveFinished"
QT_MOC_LITERAL(5, 49, 19), // "whitePlayerCantMove"
QT_MOC_LITERAL(6, 69, 19), // "blackPlayerCantMove"
QT_MOC_LITERAL(7, 89, 15), // "whitePlayerTurn"
QT_MOC_LITERAL(8, 105, 15), // "blackPlayerTurn"
QT_MOC_LITERAL(9, 121, 13), // "startNextTurn"
QT_MOC_LITERAL(10, 135, 15), // "blackPlayerMove"
QT_MOC_LITERAL(11, 151, 12), // "KReversiMove"
QT_MOC_LITERAL(12, 164, 4), // "move"
QT_MOC_LITERAL(13, 169, 15), // "whitePlayerMove"
QT_MOC_LITERAL(14, 185, 12), // "onDelayTimer"
QT_MOC_LITERAL(15, 198, 10), // "blackReady"
QT_MOC_LITERAL(16, 209, 10) // "whiteReady"

    },
    "KReversiGame\0gameOver\0\0boardChanged\0"
    "moveFinished\0whitePlayerCantMove\0"
    "blackPlayerCantMove\0whitePlayerTurn\0"
    "blackPlayerTurn\0startNextTurn\0"
    "blackPlayerMove\0KReversiMove\0move\0"
    "whitePlayerMove\0onDelayTimer\0blackReady\0"
    "whiteReady"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReversiGame[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,
       3,    0,   80,    2, 0x06 /* Public */,
       4,    0,   81,    2, 0x06 /* Public */,
       5,    0,   82,    2, 0x06 /* Public */,
       6,    0,   83,    2, 0x06 /* Public */,
       7,    0,   84,    2, 0x06 /* Public */,
       8,    0,   85,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,   86,    2, 0x08 /* Private */,
      10,    1,   87,    2, 0x08 /* Private */,
      13,    1,   90,    2, 0x08 /* Private */,
      14,    0,   93,    2, 0x08 /* Private */,
      15,    0,   94,    2, 0x08 /* Private */,
      16,    0,   95,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KReversiGame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReversiGame *_t = static_cast<KReversiGame *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gameOver(); break;
        case 1: _t->boardChanged(); break;
        case 2: _t->moveFinished(); break;
        case 3: _t->whitePlayerCantMove(); break;
        case 4: _t->blackPlayerCantMove(); break;
        case 5: _t->whitePlayerTurn(); break;
        case 6: _t->blackPlayerTurn(); break;
        case 7: _t->startNextTurn(); break;
        case 8: _t->blackPlayerMove((*reinterpret_cast< KReversiMove(*)>(_a[1]))); break;
        case 9: _t->whitePlayerMove((*reinterpret_cast< KReversiMove(*)>(_a[1]))); break;
        case 10: _t->onDelayTimer(); break;
        case 11: _t->blackReady(); break;
        case 12: _t->whiteReady(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::gameOver)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::boardChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::moveFinished)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::whitePlayerCantMove)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::blackPlayerCantMove)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::whitePlayerTurn)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KReversiGame::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReversiGame::blackPlayerTurn)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject KReversiGame::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KReversiGame.data,
      qt_meta_data_KReversiGame,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReversiGame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReversiGame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReversiGame.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KReversiGame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KReversiGame::gameOver()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KReversiGame::boardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KReversiGame::moveFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KReversiGame::whitePlayerCantMove()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KReversiGame::blackPlayerCantMove()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KReversiGame::whitePlayerTurn()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KReversiGame::blackPlayerTurn()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
