/****************************************************************************
** Meta object code from reading C++ file 'kexthighscore_gui.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kreversi-17.08.3/kexthighscore_gui.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kexthighscore_gui.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KExtHighscore__ScoresList_t {
    QByteArrayData data[1];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__ScoresList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__ScoresList_t qt_meta_stringdata_KExtHighscore__ScoresList = {
    {
QT_MOC_LITERAL(0, 0, 25) // "KExtHighscore::ScoresList"

    },
    "KExtHighscore::ScoresList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__ScoresList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KExtHighscore::ScoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KExtHighscore::ScoresList::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_KExtHighscore__ScoresList.data,
      qt_meta_data_KExtHighscore__ScoresList,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::ScoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::ScoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__ScoresList.stringdata0))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int KExtHighscore::ScoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__HighscoresList_t {
    QByteArrayData data[1];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__HighscoresList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__HighscoresList_t qt_meta_stringdata_KExtHighscore__HighscoresList = {
    {
QT_MOC_LITERAL(0, 0, 29) // "KExtHighscore::HighscoresList"

    },
    "KExtHighscore::HighscoresList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__HighscoresList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KExtHighscore::HighscoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KExtHighscore::HighscoresList::staticMetaObject = {
    { &ScoresList::staticMetaObject, qt_meta_stringdata_KExtHighscore__HighscoresList.data,
      qt_meta_data_KExtHighscore__HighscoresList,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::HighscoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HighscoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__HighscoresList.stringdata0))
        return static_cast<void*>(this);
    return ScoresList::qt_metacast(_clname);
}

int KExtHighscore::HighscoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScoresList::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__HighscoresWidget_t {
    QByteArrayData data[6];
    char stringdata0[64];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__HighscoresWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__HighscoresWidget_t qt_meta_stringdata_KExtHighscore__HighscoresWidget = {
    {
QT_MOC_LITERAL(0, 0, 31), // "KExtHighscore::HighscoresWidget"
QT_MOC_LITERAL(1, 32, 10), // "tabChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 1), // "i"
QT_MOC_LITERAL(4, 46, 9), // "changeTab"
QT_MOC_LITERAL(5, 56, 7) // "showURL"

    },
    "KExtHighscore::HighscoresWidget\0"
    "tabChanged\0\0i\0changeTab\0showURL"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__HighscoresWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   37,    2, 0x0a /* Public */,
       5,    1,   40,    2, 0x08 /* Private */,
       1,    0,   43,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

       0        // eod
};

void KExtHighscore::HighscoresWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HighscoresWidget *_t = static_cast<HighscoresWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->tabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->changeTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->showURL((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->tabChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (HighscoresWidget::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&HighscoresWidget::tabChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KExtHighscore::HighscoresWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KExtHighscore__HighscoresWidget.data,
      qt_meta_data_KExtHighscore__HighscoresWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::HighscoresWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HighscoresWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__HighscoresWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KExtHighscore::HighscoresWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KExtHighscore::HighscoresWidget::tabChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_KExtHighscore__HighscoresDialog_t {
    QByteArrayData data[10];
    char stringdata0[119];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__HighscoresDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__HighscoresDialog_t qt_meta_stringdata_KExtHighscore__HighscoresDialog = {
    {
QT_MOC_LITERAL(0, 0, 31), // "KExtHighscore::HighscoresDialog"
QT_MOC_LITERAL(1, 32, 9), // "slotUser1"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 9), // "slotUser2"
QT_MOC_LITERAL(4, 53, 10), // "tabChanged"
QT_MOC_LITERAL(5, 64, 1), // "i"
QT_MOC_LITERAL(6, 66, 20), // "highscorePageChanged"
QT_MOC_LITERAL(7, 87, 16), // "KPageWidgetItem*"
QT_MOC_LITERAL(8, 104, 7), // "newpage"
QT_MOC_LITERAL(9, 112, 6) // "before"

    },
    "KExtHighscore::HighscoresDialog\0"
    "slotUser1\0\0slotUser2\0tabChanged\0i\0"
    "highscorePageChanged\0KPageWidgetItem*\0"
    "newpage\0before"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__HighscoresDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x08 /* Private */,
       3,    0,   35,    2, 0x08 /* Private */,
       4,    1,   36,    2, 0x08 /* Private */,
       6,    2,   39,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    9,

       0        // eod
};

void KExtHighscore::HighscoresDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HighscoresDialog *_t = static_cast<HighscoresDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotUser1(); break;
        case 1: _t->slotUser2(); break;
        case 2: _t->tabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->highscorePageChanged((*reinterpret_cast< KPageWidgetItem*(*)>(_a[1])),(*reinterpret_cast< KPageWidgetItem*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPageWidgetItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KExtHighscore::HighscoresDialog::staticMetaObject = {
    { &KPageDialog::staticMetaObject, qt_meta_stringdata_KExtHighscore__HighscoresDialog.data,
      qt_meta_data_KExtHighscore__HighscoresDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::HighscoresDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::HighscoresDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__HighscoresDialog.stringdata0))
        return static_cast<void*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int KExtHighscore::HighscoresDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__LastMultipleScoresList_t {
    QByteArrayData data[1];
    char stringdata0[38];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__LastMultipleScoresList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__LastMultipleScoresList_t qt_meta_stringdata_KExtHighscore__LastMultipleScoresList = {
    {
QT_MOC_LITERAL(0, 0, 37) // "KExtHighscore::LastMultipleSc..."

    },
    "KExtHighscore::LastMultipleScoresList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__LastMultipleScoresList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KExtHighscore::LastMultipleScoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KExtHighscore::LastMultipleScoresList::staticMetaObject = {
    { &ScoresList::staticMetaObject, qt_meta_stringdata_KExtHighscore__LastMultipleScoresList.data,
      qt_meta_data_KExtHighscore__LastMultipleScoresList,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::LastMultipleScoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::LastMultipleScoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__LastMultipleScoresList.stringdata0))
        return static_cast<void*>(this);
    return ScoresList::qt_metacast(_clname);
}

int KExtHighscore::LastMultipleScoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScoresList::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__TotalMultipleScoresList_t {
    QByteArrayData data[1];
    char stringdata0[39];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__TotalMultipleScoresList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__TotalMultipleScoresList_t qt_meta_stringdata_KExtHighscore__TotalMultipleScoresList = {
    {
QT_MOC_LITERAL(0, 0, 38) // "KExtHighscore::TotalMultipleS..."

    },
    "KExtHighscore::TotalMultipleScoresList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__TotalMultipleScoresList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KExtHighscore::TotalMultipleScoresList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject KExtHighscore::TotalMultipleScoresList::staticMetaObject = {
    { &ScoresList::staticMetaObject, qt_meta_stringdata_KExtHighscore__TotalMultipleScoresList.data,
      qt_meta_data_KExtHighscore__TotalMultipleScoresList,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::TotalMultipleScoresList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::TotalMultipleScoresList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__TotalMultipleScoresList.stringdata0))
        return static_cast<void*>(this);
    return ScoresList::qt_metacast(_clname);
}

int KExtHighscore::TotalMultipleScoresList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScoresList::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__ConfigDialog_t {
    QByteArrayData data[7];
    char stringdata0[86];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__ConfigDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__ConfigDialog_t qt_meta_stringdata_KExtHighscore__ConfigDialog = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KExtHighscore::ConfigDialog"
QT_MOC_LITERAL(1, 28, 12), // "modifiedSlot"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 10), // "removeSlot"
QT_MOC_LITERAL(4, 53, 6), // "accept"
QT_MOC_LITERAL(5, 60, 9), // "slotApply"
QT_MOC_LITERAL(6, 70, 15) // "nickNameChanged"

    },
    "KExtHighscore::ConfigDialog\0modifiedSlot\0"
    "\0removeSlot\0accept\0slotApply\0"
    "nickNameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__ConfigDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x08 /* Private */,
       3,    0,   40,    2, 0x08 /* Private */,
       4,    0,   41,    2, 0x08 /* Private */,
       5,    0,   42,    2, 0x08 /* Private */,
       6,    1,   43,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void KExtHighscore::ConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ConfigDialog *_t = static_cast<ConfigDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modifiedSlot(); break;
        case 1: _t->removeSlot(); break;
        case 2: _t->accept(); break;
        case 3: _t->slotApply(); break;
        case 4: _t->nickNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KExtHighscore::ConfigDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KExtHighscore__ConfigDialog.data,
      qt_meta_data_KExtHighscore__ConfigDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::ConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::ConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__ConfigDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KExtHighscore::ConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
struct qt_meta_stringdata_KExtHighscore__AskNameDialog_t {
    QByteArrayData data[5];
    char stringdata0[64];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KExtHighscore__AskNameDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KExtHighscore__AskNameDialog_t qt_meta_stringdata_KExtHighscore__AskNameDialog = {
    {
QT_MOC_LITERAL(0, 0, 28), // "KExtHighscore::AskNameDialog"
QT_MOC_LITERAL(1, 29, 11), // "nameChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 17), // "QDialogButtonBox*"
QT_MOC_LITERAL(4, 60, 3) // "box"

    },
    "KExtHighscore::AskNameDialog\0nameChanged\0"
    "\0QDialogButtonBox*\0box"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KExtHighscore__AskNameDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KExtHighscore::AskNameDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AskNameDialog *_t = static_cast<AskNameDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast< QDialogButtonBox*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDialogButtonBox* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KExtHighscore::AskNameDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KExtHighscore__AskNameDialog.data,
      qt_meta_data_KExtHighscore__AskNameDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KExtHighscore::AskNameDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KExtHighscore::AskNameDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KExtHighscore__AskNameDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KExtHighscore::AskNameDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
