/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/kreversi-17.08.3/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReversiMainWindow_t {
    QByteArrayData data[12];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReversiMainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReversiMainWindow_t qt_meta_stringdata_KReversiMainWindow = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KReversiMainWindow"
QT_MOC_LITERAL(1, 19, 11), // "slotNewGame"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 12), // "levelChanged"
QT_MOC_LITERAL(4, 45, 20), // "slotAnimSpeedChanged"
QT_MOC_LITERAL(5, 66, 8), // "slotUndo"
QT_MOC_LITERAL(6, 75, 16), // "slotMoveFinished"
QT_MOC_LITERAL(7, 92, 12), // "slotGameOver"
QT_MOC_LITERAL(8, 105, 19), // "slotUseColoredChips"
QT_MOC_LITERAL(9, 125, 21), // "slotToggleBoardLabels"
QT_MOC_LITERAL(10, 147, 14), // "slotHighscores"
QT_MOC_LITERAL(11, 162, 15) // "slotDialogReady"

    },
    "KReversiMainWindow\0slotNewGame\0\0"
    "levelChanged\0slotAnimSpeedChanged\0"
    "slotUndo\0slotMoveFinished\0slotGameOver\0"
    "slotUseColoredChips\0slotToggleBoardLabels\0"
    "slotHighscores\0slotDialogReady"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReversiMainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x0a /* Public */,
       3,    0,   65,    2, 0x0a /* Public */,
       4,    1,   66,    2, 0x0a /* Public */,
       5,    0,   69,    2, 0x0a /* Public */,
       6,    0,   70,    2, 0x0a /* Public */,
       7,    0,   71,    2, 0x0a /* Public */,
       8,    1,   72,    2, 0x0a /* Public */,
       9,    1,   75,    2, 0x0a /* Public */,
      10,    0,   78,    2, 0x0a /* Public */,
      11,    0,   79,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KReversiMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReversiMainWindow *_t = static_cast<KReversiMainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotNewGame(); break;
        case 1: _t->levelChanged(); break;
        case 2: _t->slotAnimSpeedChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->slotUndo(); break;
        case 4: _t->slotMoveFinished(); break;
        case 5: _t->slotGameOver(); break;
        case 6: _t->slotUseColoredChips((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->slotToggleBoardLabels((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->slotHighscores(); break;
        case 9: _t->slotDialogReady(); break;
        default: ;
        }
    }
}

const QMetaObject KReversiMainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KReversiMainWindow.data,
      qt_meta_data_KReversiMainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReversiMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReversiMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReversiMainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KReversiMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
